=== modified file 'bzrlib/help.py'
--- bzrlib/help.py	2005-10-14 08:05:25 +0000
+++ bzrlib/help.py	2005-10-14 08:37:15 +0000
@@ -125,11 +125,13 @@
     outfile.write('\noptions:\n')
     for option_name, option in sorted(options.items()):
         l = '    --' + option_name
-        for shortname, longopt in Option.SHORT_OPTIONS.items():
-            if longopt.name == option_name:
-                l += ', -' + shortname
-                break
+        short_name = option.short_name()
+        if short_name:
+            assert len(short_name) == 1
+            l += ', -' + shortname
         l += (30 - len(l)) * ' ' + option.help
+        # TODO: split help over multiple lines with correct indenting and 
+        # wrapping
         outfile.write(l + '\n')
 
 

=== modified file 'bzrlib/option.py'
--- bzrlib/option.py	2005-10-14 05:34:49 +0000
+++ bzrlib/option.py	2005-10-14 08:37:15 +0000
@@ -106,46 +106,75 @@
 
 
 class Option(object):
+    """Description of a command line option"""
+    # TODO: Some way to show in help a description of the option argument
+
     OPTIONS = {}
     SHORT_OPTIONS = {}
 
-    def __init__(self, name, help='help string', type=None):
-        # need to add some description of the parameters here
+    def __init__(self, name, help='', type=None):
+        """Make a new command option.
+
+        name -- regular name of the command, used in the double-dash
+            form and also as the parameter to the command's run() 
+            method.
+
+        help -- help message displayed in command help
+
+        type -- function called to parse the option argument, or 
+            None (default) if this option doesn't take an argument.
+        """
+        # TODO: perhaps a subclass that automatically does 
+        # --option, --no-option for reversable booleans
         self.name = name
         self.help = help
         self.type = type
 
+    def short_name(self):
+        """Return the single character option for this command, if any.
+
+        Short options are globally registered.
+        """
+        return Option.SHORT_OPTIONS.get(self.name)
+
+
 def _global_option(name, **kwargs):
     """Register o as a global option."""
     Option.OPTIONS[name] = Option(name, **kwargs)
 
-_global_option('all', type=None)
+_global_option('all')
 _global_option('basis', type=str)
 _global_option('diff-options', type=str)
-_global_option('help', type=None)
+_global_option('help')
 _global_option('file', type=unicode)
-_global_option('force', type=None)
+_global_option('force')
 _global_option('format', type=unicode)
-_global_option('forward', type=None)
+_global_option('forward')
 _global_option('message', type=unicode)
-_global_option('no-recurse', type=None)
-_global_option('profile', type=None)
+_global_option('no-recurse')
+_global_option('profile')
 _global_option('revision', type=_parse_revision_str)
-_global_option('short', type=None)
-_global_option('show-ids', type=None)
+_global_option('short')
+_global_option('show-ids')
 _global_option('timezone', type=str)
-_global_option('verbose', type=None)
-_global_option('version', type=None)
-_global_option('email', type=None)
-_global_option('unchanged', type=None)
-_global_option('update', type=None)
-_global_option('long', type=None)
+_global_option('verbose')
+_global_option('version')
+_global_option('email')
+_global_option('unchanged')
+_global_option('update')
+_global_option('long')
 _global_option('root', type=str)
-_global_option('no-backup', type=None)
+_global_option('no-backup')
 _global_option('merge-type', type=_parse_merge_type)
 _global_option('pattern', type=str)
-_global_option('quiet', type=None)
-_global_option('remember', type=None)
+_global_option('quiet')
+_global_option('remember')
+
+
+def _global_short(short_name, long_name):
+    assert short_name not in Option.SHORT_OPTIONS
+    Option.SHORT_OPTIONS[short_name] = Option.OPTIONS[long_name]
+    
 
 Option.SHORT_OPTIONS['F'] = Option.OPTIONS['file']
 Option.SHORT_OPTIONS['h'] = Option.OPTIONS['help']

=== modified file 'bzrlib/shellcomplete.py'
--- bzrlib/shellcomplete.py	2005-09-09 17:12:26 +0000
+++ bzrlib/shellcomplete.py	2005-10-14 08:37:15 +0000
@@ -28,17 +28,14 @@
         outfile.write(aname + '\n')
 
 
-def shellcomplete_on_option(options, outfile = None):
-    import commands
-    
+def shellcomplete_on_option(options, outfile=None):
+    from bzrlib.option import Option
     if not options:
         return
-    
     if outfile == None:
         outfile = sys.stdout
-
     for on in options:
-        for shortname, longname in commands.SHORT_OPTIONS.items():
+        for shortname, longname in Option.SHORT_OPTIONS.items():
             if longname == on:
                 l = '"(--' + on + ' -' + shortname + ')"{--' + on + ',-' + shortname + '}'
                 break

